File locks
==========

.. autoclass:: b2sdk.v2.LegalHold()
    :no-members:
    :special-members: ON, OFF, UNSET, UNKNOWN, is_on, is_off, is_unknown

.. autoclass:: b2sdk.v2.FileRetentionSetting()
    :no-members:
    :special-members: __init__

.. autoclass:: b2sdk.v2.RetentionMode()
    :inherited-members:
    :members:

.. autoclass:: b2sdk.v2.BucketRetentionSetting()
    :no-members:
    :special-members: __init__

.. autoclass:: b2sdk.v2.RetentionPeriod()
    :inherited-members:
    :special-members: __init__

.. autoclass:: b2sdk.v2.FileLockConfiguration()
    :no-members:
    :special-members: __init__

.. autoclass:: b2sdk.v2.UNKNOWN_BUCKET_RETENTION()

.. autoclass:: b2sdk.v2.UNKNOWN_FILE_LOCK_CONFIGURATION()

.. autoclass:: b2sdk.v2.NO_RETENTION_BUCKET_SETTING()

.. autoclass:: b2sdk.v2.NO_RETENTION_FILE_SETTING()

.. autoclass:: b2sdk.v2.UNKNOWN_FILE_RETENTION_SETTING()

